[PATCHv13 6/6] gdb: only insert thread-specific breakpoints in the relevant inferior

Andrew Burgess aburgess@redhat.com
Mon Sep 23 15:36:04 GMT 2024


I spotted a comment in this commit which I'd not updated correctly as
the series developed.  I pushed the patch below to fix this.

Thanks,
Andrew

---

commit 43a1fffa62060ce640749dcc9fc17058069ccba6
Author: Andrew Burgess <aburgess@redhat.com>
Date:   Mon Sep 23 14:30:44 2024 +0100

    gdb: update comment in code_breakpoint::re_set_default
    
    Spotted a comment in code_breakpoint::re_set_default that was added in
    commit:
    
      commit 6cce025114ccd0f53cc552fde12b6329596c6c65
      Date:   Fri Mar 3 19:03:15 2023 +0000
    
          gdb: only insert thread-specific breakpoints in the relevant inferior
    
    that was incorrect.  The comment was not updated to take inferior
    specific breakpoints into account.
    
    This commit just updates the comment, there's no user visible changes
    after this commit.

diff --git a/gdb/breakpoint.c b/gdb/breakpoint.c
index 7fd50ba63fc..d161e24097a 100644
--- a/gdb/breakpoint.c
+++ b/gdb/breakpoint.c
@@ -13136,9 +13136,10 @@ code_breakpoint::re_set_default (struct program_space *filter_pspace)
 {
   std::vector<symtab_and_line> expanded, expanded_end;
 
-  /* If this breakpoint is thread-specific then find the program space in
-     which the specific thread exists.  Otherwise, for breakpoints that are
-     not thread-specific THREAD_PSPACE will be nullptr.  */
+  /* If this breakpoint is thread- or inferior-specific, then find the
+     program space in which this breakpoint exists.  Otherwise, for
+     breakpoints that are not thread- or inferior-specific, BP_PSPACE will
+     be nullptr.  */
   program_space *bp_pspace
     = find_program_space_for_breakpoint (this->thread, this->inferior);
 



More information about the Gdb-patches mailing list